$cricon-default-icon-names:
    plus,
    minus,
    edit,
    pencil,
    trash,
    arrow-up,
    arrow-down,
    arrow-left,
    arrow-right,
    chevron-up,
    chevron-down,
    chevron-left,
    chevron-right,
    check,
    search,
    close,
    user,
    calendar,
    calendar-grid,
    clock,
    flag,
    ellipsis-horizontal,
    download,
    file,
    info,
    help,
    warning,
    settings,
    bars,
    external-link,
    podcast,
    email,
    phone,
    map-marker,
    location-arrow,
    list-ul,
    list-ol,
    bold,
    italic,
    image,
    video,
    text,
    facebook,
    twitter,
    instagram,
    youtube,
    snapchat,
    shopping-cart,
    comment,
    comments,
    cut,
    copy,
    paste
;

$cricon-extra-icon-names: null !default;
