// https://css-tricks.com/full-width-containers-limited-width-parents/

%full-width { // TODO: Remove
    width: 100vw;
    position: relative;
    left: 50%;
    right: 50%;
    margin-left: -50vw;
    margin-right: -50vw;
}
