{% load cradmin_tags %}

{% if me.should_render_as_subwidgets %}
    {% for subwidget in me.iter_subwidgets %}
        {% cradmin_render_renderable subwidget %}
    {% endfor %}
{% else %}
    {{ me.rendered_field }}
    {% if me.is_checkbox_input_widget %}
        <span class="checkbox__control-indicator"></span>
    {% endif %}

{% endif %}
