"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MODAL_PLACEHOLDER_ID = void 0;
var MODAL_PLACEHOLDER_ID = 'id_modal_placeholder';
exports.MODAL_PLACEHOLDER_ID = MODAL_PLACEHOLDER_ID;