# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2018-03-07 15:23
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cradmin_temporaryfileuploadstore', '0005_auto_20180307_1622'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='TemporaryFile',
            new_name='TemporaryFileDeprecated',
        ),
    ]
