{% load cradmin_tags %}

{% block pre %}{% endblock pre %}
<{{ me.get_wrapper_htmltag }}
        {% if me.css_classes %}class="{{ me.css_classes }}"{% endif %}
        {% block list-element-attributes %}
            {% if me.get_wrapper_htmltag_id %} id="{{ me.get_wrapper_htmltag_id }}"{% endif %}
        {% endblock %}>
    {% block content %}
        {% for renderable in me.iter_renderables %}
            {% block list-item %}
                {% cradmin_render_renderable renderable %}
            {% endblock list-item %}
        {% endfor %}
    {% endblock content %}
</{{ me.get_wrapper_htmltag }}>
{% block post %}{% endblock post %}
