# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2018-03-06 03:56
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cradmin_imagearchive', '0004_auto_20180306_0447'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='ArchiveImage',
            new_name='ArchiveImageDeprecated',
        ),
    ]
