%user-select-none {
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    -o-user-select: none;
    user-select: none;

    -webkit-user-drag: none;
    -moz-user-drag: none;
    user-drag: none;
}
