@charset 'UTF-8';

/*
Basic

Colors, Breakpoints, Spacing...

Styleguide 1:basic
*/

/*
Typography

Styleguide 2:type
*/

/*
Form elements

Styleguide 3:form
*/

// Icons in bwtween (4)

/*
Screen/accessibility

Styleguide 5:screen
*/

/*
Layout

Styleguide 6:layout
*/

/*
Components

Styleguide 7:components
*/

@import '1__settings/all';
@import '2__generic/all';
@import '3__base/cricon/cricon-font-awesome';

//$cricon-font-awesome-free-icon-map: map-merge($cricon-font-awesome-free-icon-map, (
//    align-center: $fa-var-align-center,
//    align-right: $fa-var-align-right
//));
//$cricon-extra-icon-names: align-center, align-right;

@import '3__base/all';
@import '4__components/all';
